@@ -12,6 +12,9 @@ MAC_ADDR_PREFIX = [
     "B8:27:EB",
     "DC:A6:32",
     "E4:5F:01",
+    "B8-27-EB",
+    "DC-A6-32",
+    "E4-5F-01",
 ]
 
 
